=== modified file 'drizzled/nested_join.h'
--- drizzled/nested_join.h	2008-10-23 06:29:32 +0000
+++ drizzled/nested_join.h	2008-10-23 23:53:49 +0000
@@ -22,30 +22,44 @@
 
 #include <drizzled/sql_list.h>
 #include <drizzled/sql_bitmap.h>
+#include <drizzled/item.h>
+#include <drizzled/table_list.h>
 
 struct nested_join_st
 {
-  List<TableList>  join_list;       /* list of elements in the nested join */
-  table_map         used_tables;     /* bitmap of tables in the nested join */
-  table_map         not_null_tables; /* tables that rejects nulls           */
-  struct st_join_table *first_nested;/* the first nested table in the plan  */
-  /* 
+  /* list of elements in the nested join */
+  List<TableList> join_list;
+
+  /* bitmap of tables in the nested join */
+  table_map used_tables;
+
+  /* tables that rejects nulls           */
+  table_map not_null_tables;
+
+  /* the first nested table in the plan  */
+  struct st_join_table *first_nested;
+
+  /*
     Used to count tables in the nested join in 2 isolated places:
-    1. In make_outerjoin_info(). 
+    1. In make_outerjoin_info().
     2. check_interleaving_with_nj/restore_prev_nj_state (these are called
-       by the join optimizer. 
+    by the join optimizer.
     Before each use the counters are zeroed by reset_nj_counters.
   */
-  uint32_t              counter_;
-  nested_join_map   nj_map;          /* Bit used to identify this nested join*/
+  uint32_t counter_;
+
+  /* Bit used to identify this nested join*/
+  nested_join_map nj_map;
+
   /*
     (Valid only for semi-join nests) Bitmap of tables outside the semi-join
     that are used within the semi-join's ON condition.
   */
-  table_map         sj_depends_on;
+  table_map sj_depends_on;
   /* Outer non-trivially correlated tables */
-  table_map         sj_corr_tables;
-  List<Item>        sj_outer_expr_list;
+  table_map sj_corr_tables;
+
+  List<Item> sj_outer_expr_list;
 };
 
 #endif /* DRIZZLED_NESTED_JOIN_H */

=== modified file 'drizzled/sql_base.cc'
--- drizzled/sql_base.cc	2008-10-23 02:48:56 +0000
+++ drizzled/sql_base.cc	2008-10-23 23:53:49 +0000
@@ -20,6 +20,7 @@
 #include <mysys/my_dir.h>
 #include <drizzled/error.h>
 #include <drizzled/gettext.h>
+#include <drizzled/nested_join.h>
 
 #if TIME_WITH_SYS_TIME
 # include <sys/time.h>

=== modified file 'drizzled/sql_parse.cc'
--- drizzled/sql_parse.cc	2008-10-23 02:48:56 +0000
+++ drizzled/sql_parse.cc	2008-10-23 23:53:49 +0000
@@ -19,6 +19,7 @@
 #include "rpl_filter.h"
 #include "logging.h"
 #include <drizzled/error.h>
+#include <drizzled/nested_join.h>
 
 /**
   @defgroup Runtime_Environment Runtime Environment

=== modified file 'drizzled/sql_select.cc'
--- drizzled/sql_select.cc	2008-10-23 02:48:56 +0000
+++ drizzled/sql_select.cc	2008-10-23 23:53:49 +0000
@@ -31,6 +31,7 @@
 #include <drizzled/error.h>
 #include <drizzled/gettext.h>
 #include <drizzled/util/test.h>
+#include <drizzled/nested_join.h>
 
 const char *join_type_str[]={ "UNKNOWN","system","const","eq_ref","ref",
 			      "MAYBE_REF","ALL","range","index",

=== modified file 'drizzled/sql_yacc.yy'
--- drizzled/sql_yacc.yy	2008-10-23 02:48:56 +0000
+++ drizzled/sql_yacc.yy	2008-10-23 23:53:49 +0000
@@ -41,6 +41,7 @@
 #include "lex_symbol.h"
 #include <storage/myisam/myisam.h>
 #include <drizzled/error.h>
+#include <drizzled/nested_join.h>
 
 int yylex(void *yylval, void *yysession);
 

=== modified file 'drizzled/table.cc'
--- drizzled/table.cc	2008-10-23 02:48:56 +0000
+++ drizzled/table.cc	2008-10-23 23:53:49 +0000
@@ -22,8 +22,9 @@
 #include <drizzled/error.h>
 #include <drizzled/gettext.h>
 
-#include "tmp_table.h"
-#include "sj_tmp_table.h"
+#include <drizzled/tmp_table.h>
+#include <drizzled/sj_tmp_table.h>
+#include <drizzled/nested_join.h>
 
 #include <string>
 

=== modified file 'drizzled/table.h'
--- drizzled/table.h	2008-10-20 04:28:21 +0000
+++ drizzled/table.h	2008-10-23 23:53:49 +0000
@@ -27,7 +27,6 @@
 #include <drizzled/order.h>
 #include <drizzled/filesort_info.h>
 #include <drizzled/natural_join_column.h>
-#include <drizzled/nested_join.h>
 #include <drizzled/field_iterator.h>
 
 class Item;				/* Needed by order_st */

=== modified file 'drizzled/table_list.h'
--- drizzled/table_list.h	2008-10-20 04:28:21 +0000
+++ drizzled/table_list.h	2008-10-23 23:53:49 +0000
@@ -71,8 +71,10 @@
 class Item_subselect;
 class Table;
 
+struct nested_join_st;
+
 enum enum_schema_table_state
-{ 
+{
   NOT_PROCESSED= 0,
   PROCESSED_BY_CREATE_SORT_INDEX,
   PROCESSED_BY_JOIN_EXEC

